@@ -172,7 +172,7 @@ pango_script_iter_free (PangoScriptIter *iter)
  * @script: location to store script for range, or %NULL
  * 
  * Gets information about the range to which @iter currently points.
- * The range is the is the set of locations p where *start <= p < *end.
+ * The range is the set of locations p where *start <= p < *end.
  * (That is, it doesn't include the character stored at *end)
  **/
 void
@@ -535,6 +535,18 @@ pango_script_get_sample_language (PangoScript script)
     "",    /* PANGO_SCRIPT_LINEAR_B */
     "",    /* PANGO_SCRIPT_TAI_LE */
     "uga", /* PANGO_SCRIPT_UGARITIC */
+    
+    "",    /* PANGO_SCRIPT_NEW_TAI_LUE */
+    "bug", /* PANGO_SCRIPT_BUGINESE */
+    /* The original script for Old Church Slavonic (chu), later
+     * written with Cyrillic */
+    "",    /* PANGO_SCRIPT_GLAGOLITIC */
+    /* Used for for Berber (ber), but Arabic script is more common */
+    "",    /* PANGO_SCRIPT_TIFINAGH */
+    /* Syloti Nagri is used for Sylheti, no ISO 639 code */
+    "",    /* PANGO_SCRIPT_SYLOTI_NAGRI */
+    "peo", /* PANGO_SCRIPT_OLD_PERSIAN */
+    "",    /*  PANGO_SCRIPT_KHAROSHTHI */
   };
   const char *sample_language;
   
